# Project Description
Pytitanum is a library which provides a simple implementations
of selenium functionality
## Installation steps
### To Install Pytitanium, simply run the following command 
> pip install PyTitanium